@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 2003, 2006 Free Software Foundation, Inc.
+ * Copyright 2003, 2006, 2007 Free Software Foundation, Inc.
  * Written by Paolo Bonzini.
  *
  * This file is part of GNU Smalltalk.
@@ -103,11 +103,18 @@ int win_recv(int fd, void* buffer, int n, int flags);
 
 #else /* !__MSVCRT__ */
 
+#include <sys/types.h>
+#include <sys/time.h>
+#include <unistd.h>
 #include <errno.h>
+#ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
+#endif
 #include <sys/socket.h>
 #include <netdb.h>
 #include <netinet/in.h>
+#include <netinet/tcp.h>
+
 #define closesocket(x)            close(x)
 #define is_socket_error(err)      (errno == (err))
 #define clear_socket_error()      (errno = 0)
