@@ -115,7 +115,6 @@ extern void _gst_pop_stream (mst_Boolean closeIt)
    a subsection of a real file via a temporary file what the real
    source of the text is.  */
 extern void _gst_set_stream_info (int line,
-				  OOP fileOOP,
 				  OOP fileNameOOP,
 				  int fileOffset) 
   ATTRIBUTE_HIDDEN;
@@ -175,6 +174,12 @@ extern stream_type _gst_get_cur_stream_type (void)
   ATTRIBUTE_PURE 
   ATTRIBUTE_HIDDEN;
 
+/* Return the name of the topmost stream in the stack if it is of type
+   STREAM_FILE; nil otherwise.  */
+extern OOP _gst_get_cur_file_name (void)
+  ATTRIBUTE_PURE 
+  ATTRIBUTE_HIDDEN;
+
 /* Returns an OOP containing the string of the topmost stream if it is
    a STREAM_STRING, STREAM_OOP or STREAM_READLINE, or if it has a filename;
    nil otherwise.  */
